'use strict';

var m3 = {b:2};

module.exports = m3;
